# ChromaticTools
[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/chromaticisobar/chromatictools/package/main?event=push)](https://github.com/chromaticisobar/chromatictools/actions?query=workflow%3Apackage)
[![Coverage](https://gist.githubusercontent.com/ChromaticIsobar/0836432975c68f652f9868ed24ef696c/raw/chromatictools-coverage-badge.svg)](https://github.com/chromaticisobar/chromatictools/actions?query=workflow%3Apackage)
[![Pylint](https://gist.githubusercontent.com/ChromaticIsobar/956da0682e378a1880d70f242c3315b5/raw/chromatictools-pylint-badge.svg)](https://github.com/chromaticisobar/chromatictools/actions?query=workflow%3Apackage)
[![PyPI version](https://badge.fury.io/py/chromatictools.svg)](https://badge.fury.io/py/chromatictools)

This is a collection of utilities that I often use when writing other software

## Install
You can install the `chromatictools` package from [PyPI](https://pypi.org/project/chromatictools) via pip

```pip install chromatictools```

## Documentation
API documentation can be found online here:

https://chromaticisobar.github.io/chromatictools

## Source code
Source code is available on GitHub

https://github.com/chromaticisobar/chromatictools
